﻿var scriptName = "Make book",
doc;

Main();

//===================================== FUNCTIONS ======================================
function Main() {
	var inddFile;
	if (File.fs != "Macintosh") ErrorExit("This script is for MAC only: buy yourself a MAC and try again.", true);
	var excelFile = File.openDialog("Pick the excel file", function(file) { return file instanceof Folder || (!(file.hidden) && (file.name.match(/\.xlsx$/i))); }, false);
	if (excelFile != null) {
		var excelFilePath = excelFile.fsName;
		var fixedExcelFilePath = excelFilePath.replace("/Volumes/", "").replace(/\//g, ":");
		var splitCharRows = "|";
		var splitCharColumns = ";";
		var sheetNumber = "1";
		var data = GetDataFromExcelMac(fixedExcelFilePath, splitCharRows, splitCharColumns, sheetNumber);
		var list = NormalizeData(data);
		
		if ( list.length > 0 ) {
			var myBookFileName = excelFilePath.replace(/xlsx$/, "indb");
			myBookFile = new File( myBookFileName );
			if ( myBookFile.exists ) {
				ErrorExit("The book already exists in this location and with the same name: " + fixedExcelFilePath, true);
			}
			else {
				 myBook = app.books.add( myBookFile );
				 myBook.automaticPagination = false;
				 				 
				 for ( i=0; i < list.length; i++ ) {
					 inddFile = new File(list[i]);
					 if (inddFile.exists) {
						myBook.bookContents.add( File(list[i]) );
					}
				 }
				 myBook.save( );
			}
		}
	}
}
//--------------------------------------------------------------------------------------------------------------------------------------------------------
function NormalizeData(data) {
	var list = [];
	
	for (var i = 0; i < data.length; i++) {
		list.push(data[i][0]);
	}

	return list;
}
//--------------------------------------------------------------------------------------------------------------------------------------------------------
function GetDataFromExcelMac(excelFilePath, splitCharRows, splitCharColumns, sheetNumber) {
	if (File.fs != "Macintosh") return null;
	if (typeof splitCharRows === "undefined") var splitCharRows = "|";
	if (typeof splitCharColumns === "undefined") var splitCharColumns = ";";
	if (typeof sheetNumber === "undefined") var sheetNumber = "1";

	var appVersion,
	appVersionNum = Number(String(app.version).split(".")[0]);
	
	switch (appVersionNum) {
		case 15:
			appVersion = "2020";
			break;
		case 14:
			appVersion = "CC 2019";
			break;
		case 13:
			appVersion = "CC 2018";
			break;
		case 12:
			appVersion = "CC 2017";
			break;
		case 11:
			appVersion = "CC 2015";
			break;
		case 10:
			appVersion = "CC 2014";
			break;			
		case 9:
			appVersion = "CC";
			break;		
		case 8:
			appVersion = "CS 6";
			break;
		case 7:
			if (app.version.match(/^7\.5/) != null) {
				appVersion = "CS 5.5";
			}
			else {
				appVersion = "CS 5";
			}
			break;
		case 6:
			appVersion = "CS 4";
			break;
		case 5:
			appVersion = "CS 3";
			break;
		case 4:
			appVersion = "CS 2";
			break;
		case 3:
			appVersion = "CS";
			break;			
		default:
		return null;
	}

	var as = 'tell application "Microsoft Excel"\r';
	as += 'open file \"' + excelFilePath + '\"\r';
	as += 'set theWorkbook to active workbook\r';
	as += 'set theSheet to sheet ' + sheetNumber + ' of theWorkbook\r';
	as += 'set theMatrix to value of used range of theSheet\r';
	as += 'set theRowCount to count theMatrix\r';
	as += 'set str to ""\r';
	as += 'set oldDelimiters to AppleScript\'s text item delimiters\r';
	as += 'repeat with countRows from 1 to theRowCount\r';
	as += 'set theRow to item countRows of theMatrix\r';
	as += 'set AppleScript\'s text item delimiters to \"' + splitCharColumns + '\"\r';
	as += 'set str to str & (theRow as string) & \"' + splitCharRows + '\"\r';
	as += 'end repeat\r';
	as += 'set AppleScript\'s text item delimiters to oldDelimiters\r';
	as += 'close theWorkbook saving no\r';
	as += 'end tell\r';
	as += 'tell application "Adobe InDesign ' + appVersion + '\"\r';
	as += 'tell script args\r';
	as += 'set value name "excelData" value str\r';
	as += 'end tell\r';
	as += 'end tell';
	
	if (appVersionNum > 5) { // CS4 and above
		app.doScript(as, ScriptLanguage.APPLESCRIPT_LANGUAGE, undefined, UndoModes.ENTIRE_SCRIPT);
	}
	else { // CS3 and below
		app.doScript(as, ScriptLanguage.APPLESCRIPT_LANGUAGE);
	}

	var str = app.scriptArgs.getValue("excelData");
	app.scriptArgs.clear();
	
	var tempArrLine, line,
	data = [],
	tempArrData = str.split(splitCharRows);
	
	for (var i = 0; i < tempArrData.length; i++) {
		line = tempArrData[i];
		if (line == "") continue;
		tempArrLine = line.split(splitCharColumns);
		data.push(tempArrLine);
	}
	
	return data;
}
//--------------------------------------------------------------------------------------------------------------------------------------------------------
function ErrorExit(error, icon) {
	alert(error, scriptName, icon);
	exit();
}
//--------------------------------------------------------------------------------------------------------------------------------------------------------